#[non_exhaustive]pub struct CargoSetInputs<'g> {
pub options: CargoOptions<'g>,
pub features_only: FeatureSet<'g>,
}Expand description
The inputs to a CargoSet other than the initials.
The initials are kept separate so that one CargoSetInputs can be reused
across many CargoSets via to_cargo_set.
Both fields must refer to the same PackageGraph as the initials they
are used with.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.options: CargoOptions<'g>The Cargo options used to build the CargoSet.
features_only: FeatureSet<'g>The features-only set: see CargoSet::new.
Implementations
Sourceimpl<'g> CargoSetInputs<'g>
impl<'g> CargoSetInputs<'g>
Sourcepub fn new(options: CargoOptions<'g>, features_only: FeatureSet<'g>) -> Self
pub fn new(options: CargoOptions<'g>, features_only: FeatureSet<'g>) -> Self
Creates a new CargoSetInputs from the given inputs.
Sourcepub fn to_cargo_set(
&self,
initials: FeatureSet<'g>,
) -> Result<CargoSet<'g>, Error>
pub fn to_cargo_set( &self, initials: FeatureSet<'g>, ) -> Result<CargoSet<'g>, Error>
Simulates a Cargo build of initials with these inputs.
This is a shorthand for CargoSet::new.
Panics
Panics if initials was built from a different package graph than
these inputs.