CargoLinkVisitor

Trait CargoLinkVisitor 

pub trait CargoLinkVisitor<'g> {
    // Required method
    fn visit_link(
        &mut self,
        cx: &CargoLinkContext<'_, 'g>,
        link: PackageLink<'g>,
    ) -> bool;
}
Represents whether a particular link within a package graph should be followed while building a CargoSet.

This is similar to PackageLinkVisitor, but is passed a CargoLinkContext with additional information about the Cargo build.

Required Methods

Returns true if this link should be followed.

Returning false does not prevent the to package from being included if it’s reachable through other means.