EnabledStatus

Struct EnabledStatus 

pub struct EnabledStatus<'g> { /* private fields */ }
Whether a dependency or feature is required, optional, or disabled.

Returned by the methods on DependencyMetadata.

Examples

[dependencies]
once_cell = "1"

The dependency and default features are required on all platforms.

[dependencies]
once_cell = { version = "1", optional = true }

The dependency and default features are optional on all platforms.

[target.'cfg(windows)'.dependencies]
once_cell = { version = "1", optional = true }

The result is platform-dependent. On Windows, the dependency and default features are both optional. On non-Windows platforms, the dependency and default features are disabled.

[dependencies]
once_cell = { version = "1", optional = true }

[target.'cfg(windows)'.dependencies]
once_cell = { version = "1", optional = false, default-features = false }

The result is platform-dependent. On Windows, the dependency is mandatory and default features are optional (i.e. enabled if the once_cell feature is turned on).

On Unix platforms, the dependency and default features are both optional.

Implementations

Source

impl<'g> EnabledStatus<'g>

pub fn is_never(&self) -> bool

Returns true if this dependency is never enabled on any platform.

pub fn required_on(&self, platform_spec: &PlatformSpec) -> EnabledTernary

Evaluates whether this dependency is required on the given platform spec.

Returns Unknown if the result was unknown, which may happen if evaluating against PlatformSpec::Platforms and the target features of one of its platforms are unknown.

pub fn enabled_on(&self, platform_spec: &PlatformSpec) -> EnabledTernary

Evaluates whether this dependency is enabled (required or optional) on the given platform spec.

Returns Unknown if the result was unknown, which may happen if evaluating against PlatformSpec::Platforms and the target features of one of its platforms are unknown.

pub fn required_status(&self) -> PlatformStatus<'g>

Returns the PlatformStatus corresponding to whether this dependency is required.

pub fn optional_status(&self) -> PlatformStatus<'g>

Returns the PlatformStatus corresponding to whether this dependency is optional.