pub struct PackageLink<'g> { /* private fields */ }
Represents a dependency from one package to another.

This struct contains information about:

  • whether this dependency was renamed in the context of this crate.
  • if this is a normal, dev and/or build dependency.
  • platform-specific information about required, optional and status

Implementations

Returns the package which depends on the to package.

Returns the package which is depended on by the from package.

Returns the endpoints as a pair of packages (from, to).

Returns the name for this dependency edge. This can be affected by a crate rename.

Returns the resolved name for this dependency edge. This may involve renaming the crate and replacing - with _.

Returns the semver requirements specified for this dependency.

To get the resolved version, see the to field of the PackageLink this was part of.

Notes

A dependency can be requested multiple times, possibly with different version requirements, even if they all end up resolving to the same version. version_req will return any of those requirements.

See Specifying Dependencies in the Cargo reference for more details.

Returns details about this dependency from the [dependencies] section.

Returns details about this dependency from the [build-dependencies] section.

Returns details about this dependency from the [dev-dependencies] section.

Returns details about this dependency from the section specified by the given dependency kind.

Return true if this edge is dev-only, i.e. code from this edge will not be included in normal builds.