pub struct PackageQuery<'g> { /* private fields */ }Expand description
A query over a package graph.
This is the entry point for iterators over IDs and dependency links, and dot graph presentation.
A PackageQuery is constructed through the query_ methods on PackageGraph.
Implementations
Sourceimpl<'g> PackageQuery<'g>
impl<'g> PackageQuery<'g>
Sourcepub fn graph(&self) -> &'g PackageGraph
pub fn graph(&self) -> &'g PackageGraph
Returns the package graph on which the query is going to be executed.
Sourcepub fn direction(&self) -> DependencyDirection
pub fn direction(&self) -> DependencyDirection
Returns the direction the query is happening in.
Sourcepub fn initials(&self) -> &PackageSet<'g>
pub fn initials(&self) -> &PackageSet<'g>
Returns the set of initial packages specified in the query.
Sourcepub fn to_feature_query(
&self,
filter: impl FeatureFilter<'g>,
) -> FeatureQuery<'g>
pub fn to_feature_query( &self, filter: impl FeatureFilter<'g>, ) -> FeatureQuery<'g>
Converts this PackageQuery into a FeatureQuery, using the given feature filter.
This will cause the feature graph to be constructed if it hasn’t been done so already.
Sourcepub fn resolve(self) -> PackageSet<'g>
pub fn resolve(self) -> PackageSet<'g>
Resolves this query into a set of known packages, following every link found along the way.
This is the entry point for iterators.
Sourcepub fn resolve_with(
self,
visitor: impl PackageLinkVisitor<'g>,
) -> PackageSet<'g>
pub fn resolve_with( self, visitor: impl PackageLinkVisitor<'g>, ) -> PackageSet<'g>
Resolves this query into a set of known packages, using the provided visitor to determine which links are followed.
Sourcepub fn resolve_with_fn(
self,
visitor_fn: impl FnMut(&PackageLinkContext<'g>, PackageLink<'g>) -> bool,
) -> PackageSet<'g>
pub fn resolve_with_fn( self, visitor_fn: impl FnMut(&PackageLinkContext<'g>, PackageLink<'g>) -> bool, ) -> PackageSet<'g>
Resolves this query into a set of known packages, using the provided visitor function to determine which links are followed.