EnabledTernary

Enum EnabledTernary 

pub enum EnabledTernary {
    Disabled,
    Unknown,
    Enabled,
}
Whether a dependency or feature is enabled on a specific platform.

This is a ternary or three-valued logic because the result may be unknown in some situations.

Returned by the methods on EnabledStatus, PlatformStatus, and PlatformEval.

Variants



Disabled

The dependency is disabled on this platform.



Unknown

The status of this dependency is unknown on this platform.

This may happen if evaluation involves unknown target features. Notably, this will not be returned when evaluating only against Platform::build_target(), since the target features for the build target platform are determined at compile time.



Enabled

The dependency is enabled on this platform.

Implementations

Source

impl EnabledTernary

pub fn is_known(self) -> bool

Returns true if the status is known (either enabled or disabled).