pub struct CargoLinkContext<'a, 'g> { /* private fields */ }Expand description
Context passed to a CargoLinkVisitor for each link visited while
building a CargoSet.
Implementations
Sourceimpl<'a, 'g> CargoLinkContext<'a, 'g>
impl<'a, 'g> CargoLinkContext<'a, 'g>
Sourcepub fn package_context(&self) -> &PackageLinkContext<'g>
pub fn package_context(&self) -> &PackageLinkContext<'g>
Returns the context for the underlying package graph traversal.
Sourcepub fn build_platform(&self) -> BuildPlatform
pub fn build_platform(&self) -> BuildPlatform
Returns the platform this link is being evaluated for: the target pass or the host pass.
Sourcepub fn platform_spec(&self) -> &PlatformSpec
pub fn platform_spec(&self) -> &PlatformSpec
Returns the platform spec that normal and dev dependencies are evaluated against in this pass.
Sourcepub fn build_dep_platform_spec(&self) -> &PlatformSpec
pub fn build_dep_platform_spec(&self) -> &PlatformSpec
Returns the platform spec that build dependencies are evaluated against in this pass (always the host platform).
Sourcepub fn considers_dev_deps(&self, link: &PackageLink<'g>) -> bool
pub fn considers_dev_deps(&self, link: &PackageLink<'g>) -> bool
Returns true if dev-dependencies of this link may be followed:
CargoOptions::set_include_dev is set and the from package is an
initial.
Sourcepub fn considers_build_deps(&self, link: &PackageLink<'g>) -> bool
pub fn considers_build_deps(&self, link: &PackageLink<'g>) -> bool
Returns true if build-dependencies of this link may be followed: the
from package has a build script.